"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, health_check_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets status of a specified health check.   This API is intended for use during development to diagnose behavior. It doesn’t support production use-cases with high query rates that require immediate and actionable responses.

    Args:
        health_check_id(str): The ID for the health check that you want the current status for. When you created the health check, CreateHealthCheck returned the ID in the response, in the HealthCheckId element.  If you want to check the status of a calculated health check, you must use the Amazon Route 53 console or the CloudWatch console. You can't use GetHealthCheckStatus to get the status of a calculated health check. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.health_check.status.get(ctx, health_check_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.health_check.status.get health_check_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_health_check_status",
        op_kwargs={"HealthCheckId": health_check_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, app_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Generates a one-time challenge code to authenticate a user into your Amplify Admin UI.

    Args:
        app_id(str): The app ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.token.create(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.token.create app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="create_token",
        op_kwargs={"AppId": app_id},
    )


async def delete(hub, ctx, app_id: str, session_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the challenge token based on the given appId and sessionId.

    Args:
        app_id(str): The app ID.
        session_id(str): The session ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.token.delete(ctx, app_id=value, session_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.token.delete app_id=value, session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="delete_token",
        op_kwargs={"AppId": app_id, "SessionId": session_id},
    )


async def get(hub, ctx, app_id: str, session_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the challenge token based on the given appId and sessionId.

    Args:
        app_id(str): The app ID.
        session_id(str): The session ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.token.get(ctx, app_id=value, session_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.token.get app_id=value, session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="get_token",
        op_kwargs={"AppId": app_id, "SessionId": session_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, name: str, run_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Represents one run of a DataBrew job.

    Args:
        name(str): The name of the job being processed during this run.
        run_id(str): The unique identifier of the job run.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.job.run.describe(ctx, name=value, run_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.job.run.describe name=value, run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="describe_job_run",
        op_kwargs={"Name": name, "RunId": run_id},
    )


async def list_all(
    hub, ctx, name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the previous runs of a particular DataBrew job.

    Args:
        name(str): The name of the job.
        max_results(int, optional): The maximum number of results to return in this request. . Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.job.run.list_all(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.job.run.list_all name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="list_job_runs",
        op_kwargs={"Name": name, "MaxResults": max_results, "NextToken": next_token},
    )


async def start(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Runs a DataBrew job.

    Args:
        name(str): The name of the job to be run.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.job.run.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.job.run.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="start_job_run",
        op_kwargs={"Name": name},
    )


async def stop(hub, ctx, name: str, run_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a particular run of a job.

    Args:
        name(str): The name of the job to be stopped.
        run_id(str): The ID of the job run to be stopped.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.job.run.stop(ctx, name=value, run_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.job.run.stop name=value, run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="stop_job_run",
        op_kwargs={"Name": name, "RunId": run_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disconnect(hub, ctx, connection_token: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Disconnects a participant. Note that ConnectionToken is used for invoking this API instead of ParticipantToken. The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.

    Args:
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        connection_token(str): The authentication token associated with the participant's connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connectparticipant.participant.init.disconnect(
                ctx, connection_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connectparticipant.participant.init.disconnect connection_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connectparticipant",
        operation="disconnect_participant",
        op_kwargs={"ClientToken": client_token, "ConnectionToken": connection_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    key_id: str,
    grantee_principal: str,
    operations: List,
    retiring_principal: str = None,
    constraints: Dict = None,
    grant_tokens: List = None,
    name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a grant to a customer master key (CMK).  A grant is a policy instrument that allows AWS principals to use AWS KMS customer master keys (CMKs) in cryptographic operations. It also can allow them to view a CMK (DescribeKey) and create and manage grants. When authorizing access to a CMK, grants are considered along with key policies and IAM policies. Grants are often used for temporary permissions because you can create one, use its permissions, and delete it without changing your key policies or IAM policies.  For detailed information about grants, including grant terminology, see Using grants in the  AWS Key Management Service Developer Guide . For examples of working with grants in several programming languages, see Programming grants. The CreateGrant operation returns a GrantToken and a GrantId.   When you create, retire, or revoke a grant, there might be a brief delay, usually less than five minutes, until the grant is available throughout AWS KMS. This state is known as eventual consistency. Once the grant has achieved eventual consistency, the grantee principal can use the permissions in the grant without identifying the grant.  However, to use the permissions in the grant immediately, use the GrantToken that CreateGrant returns. For details, see Using a grant token in the  AWS Key Management Service Developer Guide .   The CreateGrant operation also returns a GrantId. You can use the GrantId and a key identifier to identify the grant in the RetireGrant and RevokeGrant operations. To find the grant ID, use the ListGrants or ListRetirableGrants operations.   For information about symmetric and asymmetric CMKs, see Using Symmetric and Asymmetric CMKs in the AWS Key Management Service Developer Guide. For more information about grants, see Grants in the  AWS Key Management Service Developer Guide . The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: Yes. To perform this operation on a CMK in a different AWS account, specify the key ARN in the value of the KeyId parameter.   Required permissions: kms:CreateGrant (key policy)  Related operations:     ListGrants     ListRetirableGrants     RetireGrant     RevokeGrant

    Args:
        key_id(str): Identifies the customer master key (CMK) for the grant. The grant gives principals permission to use this CMK. Specify the key ID or key ARN of the CMK. To specify a CMK in a different AWS account, you must use the key ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        grantee_principal(str): The identity that gets the permissions specified in the grant. To specify the principal, use the Amazon Resource Name (ARN) of an AWS principal. Valid AWS principals include AWS accounts (root), IAM users, IAM roles, federated users, and assumed role users. For examples of the ARN syntax to use for specifying a principal, see AWS Identity and Access Management (IAM) in the Example ARNs section of the AWS General Reference.
        retiring_principal(str, optional): The principal that is given permission to retire the grant by using RetireGrant operation. To specify the principal, use the Amazon Resource Name (ARN) of an AWS principal. Valid AWS principals include AWS accounts (root), IAM users, federated users, and assumed role users. For examples of the ARN syntax to use for specifying a principal, see AWS Identity and Access Management (IAM) in the Example ARNs section of the AWS General Reference. Defaults to None.
        operations(List): A list of operations that the grant permits.  The operation must be supported on the CMK. For example, you cannot create a grant for a symmetric CMK that allows the Sign operation, or a grant for an asymmetric CMK that allows the GenerateDataKey operation. If you try, AWS KMS returns a ValidationError exception. For details, see Grant operations in the AWS Key Management Service Developer Guide.
        constraints(Dict, optional): Specifies a grant constraint.  AWS KMS supports the EncryptionContextEquals and EncryptionContextSubset grant constraints. Each constraint value can include up to 8 encryption context pairs. The encryption context value in each constraint cannot exceed 384 characters. These grant constraints allow a cryptographic operation only when the encryption context in the request matches (EncryptionContextEquals) or includes (EncryptionContextSubset) the encryption context specified in this structure. For more information about encryption context, see Encryption Context in the  AWS Key Management Service Developer Guide . For information about grant constraints, see Using grant constraints in the AWS Key Management Service Developer Guide. The encryption context grant constraints are supported only on operations that include an encryption context. You cannot use an encryption context grant constraint for cryptographic operations with asymmetric CMKs or for management operations, such as DescribeKey or RetireGrant. Defaults to None.
        grant_tokens(List, optional): A list of grant tokens.  Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.
        name(str, optional): A friendly name for the grant. Use this value to prevent the unintended creation of duplicate grants when retrying this request. When this value is absent, all CreateGrant requests result in a new grant with a unique GrantId even if all the supplied parameters are identical. This can result in unintended duplicates when you retry the CreateGrant request. When this value is present, you can retry a CreateGrant request with identical parameters; if the grant already exists, the original GrantId is returned without creating a new grant. Note that the returned grant token is unique with every CreateGrant request, even when a duplicate GrantId is returned. All grant tokens for the same grant ID can be used interchangeably. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.grant.create(
                ctx, key_id=value, grantee_principal=value, operations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.grant.create key_id=value, grantee_principal=value, operations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="create_grant",
        op_kwargs={
            "KeyId": key_id,
            "GranteePrincipal": grantee_principal,
            "RetiringPrincipal": retiring_principal,
            "Operations": operations,
            "Constraints": constraints,
            "GrantTokens": grant_tokens,
            "Name": name,
        },
    )


async def list_all(
    hub,
    ctx,
    key_id: str,
    limit: int = None,
    marker: str = None,
    grant_id: str = None,
    grantee_principal: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of all grants for the specified customer master key (CMK).  You must specify the CMK in all requests. You can filter the grant list by grant ID or grantee principal.  The GranteePrincipal field in the ListGrants response usually contains the user or role designated as the grantee principal in the grant. However, when the grantee principal in the grant is an AWS service, the GranteePrincipal field contains the service principal, which might represent several different grantee principals.   Cross-account use: Yes. To perform this operation on a CMK in a different AWS account, specify the key ARN in the value of the KeyId parameter.  Required permissions: kms:ListGrants (key policy)  Related operations:     CreateGrant     ListRetirableGrants     RetireGrant     RevokeGrant

    Args:
        limit(int, optional): Use this parameter to specify the maximum number of items to return. When this value is present, AWS KMS does not return more than the specified number of items, but it might return fewer. This value is optional. If you include a value, it must be between 1 and 100, inclusive. If you do not include a value, it defaults to 50. Defaults to None.
        marker(str, optional): Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextMarker from the truncated response you just received. Defaults to None.
        key_id(str): Returns only grants for the specified customer master key (CMK). This parameter is required. Specify the key ID or key ARN of the CMK. To specify a CMK in a different AWS account, you must use the key ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        grant_id(str, optional): Returns only the grant with the specified grant ID. The grant ID uniquely identifies the grant. . Defaults to None.
        grantee_principal(str, optional): Returns only grants where the specified principal is the grantee principal for the grant. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.grant.list_all(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.grant.list_all key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="list_grants",
        op_kwargs={
            "Limit": limit,
            "Marker": marker,
            "KeyId": key_id,
            "GrantId": grant_id,
            "GranteePrincipal": grantee_principal,
        },
    )


async def retire(
    hub, ctx, grant_token: str = None, key_id: str = None, grant_id: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes a grant. Typically, you retire a grant when you no longer need its permissions. To identify the grant to retire, use a grant token, or both the grant ID and a key identifier (key ID or key ARN) of the customer master key (CMK). The CreateGrant operation returns both values. This operation can be called by the retiring principal for a grant, by the grantee principal if the grant allows the RetireGrant operation, and by the AWS account (root user) in which the grant is created. It can also be called by principals to whom permission for retiring a grant is delegated. For details, see Retiring and revoking grants in the AWS Key Management Service Developer Guide. For detailed information about grants, including grant terminology, see Using grants in the  AWS Key Management Service Developer Guide . For examples of working with grants in several programming languages, see Programming grants.  Cross-account use: Yes. You can retire a grant on a CMK in a different AWS account.  Required permissions::Permission to retire a grant is determined primarily by the grant. For details, see Retiring and revoking grants in the AWS Key Management Service Developer Guide.  Related operations:     CreateGrant     ListGrants     ListRetirableGrants     RevokeGrant

    Args:
        grant_token(str, optional): Identifies the grant to be retired. You can use a grant token to identify a new grant even before it has achieved eventual consistency. Only the CreateGrant operation returns a grant token. For details, see Grant token and Eventual consistency in the AWS Key Management Service Developer Guide. Defaults to None.
        key_id(str, optional): The key ARN CMK associated with the grant. To find the key ARN, use the ListKeys operation. For example: arn:aws:kms:us-east-2:444455556666:key/1234abcd-12ab-34cd-56ef-1234567890ab . Defaults to None.
        grant_id(str, optional): Identifies the grant to retire. To get the grant ID, use CreateGrant, ListGrants, or ListRetirableGrants.   Grant ID Example - 0123456789012345678901234567890123456789012345678901234567890123  . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.grant.retire(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.grant.retire
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="retire_grant",
        op_kwargs={"GrantToken": grant_token, "KeyId": key_id, "GrantId": grant_id},
    )


async def revoke(hub, ctx, key_id: str, grant_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified grant. You revoke a grant to terminate the permissions that the grant allows. For more information, see Retiring and revoking grants in the  AWS Key Management Service Developer Guide . When you create, retire, or revoke a grant, there might be a brief delay, usually less than five minutes, until the grant is available throughout AWS KMS. This state is known as eventual consistency. For details, see Eventual consistency in the  AWS Key Management Service Developer Guide .   Cross-account use: Yes. To perform this operation on a CMK in a different AWS account, specify the key ARN in the value of the KeyId parameter.  Required permissions: kms:RevokeGrant (key policy).  Related operations:     CreateGrant     ListGrants     ListRetirableGrants     RetireGrant

    Args:
        key_id(str): A unique identifier for the customer master key (CMK) associated with the grant. To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. Specify the key ID or key ARN of the CMK. To specify a CMK in a different AWS account, you must use the key ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        grant_id(str): Identifies the grant to revoke. To get the grant ID, use CreateGrant, ListGrants, or ListRetirableGrants.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.grant.revoke(ctx, key_id=value, grant_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.grant.revoke key_id=value, grant_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="revoke_grant",
        op_kwargs={"KeyId": key_id, "GrantId": grant_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, flow_arn: str, vpc_interfaces: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds VPC interfaces to flow

    Args:
        flow_arn(str): The flow that you want to mutate.
        vpc_interfaces(List): A list of VPC interfaces that you want to add.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.vpc_interface.add(
                ctx, flow_arn=value, vpc_interfaces=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.vpc_interface.add flow_arn=value, vpc_interfaces=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="add_flow_vpc_interfaces",
        op_kwargs={"FlowArn": flow_arn, "VpcInterfaces": vpc_interfaces},
    )


async def remove(hub, ctx, flow_arn: str, vpc_interface_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a VPC Interface from an existing flow. This request can be made only on a VPC interface that does not have a Source or Output associated with it. If the VPC interface is referenced by a Source or Output, you must first delete or update the Source or Output to no longer reference the VPC interface.

    Args:
        flow_arn(str): The flow that you want to remove a VPC interface from.
        vpc_interface_name(str): The name of the VPC interface that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.vpc_interface.remove(
                ctx, flow_arn=value, vpc_interface_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.vpc_interface.remove flow_arn=value, vpc_interface_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="remove_flow_vpc_interface",
        op_kwargs={"FlowArn": flow_arn, "VpcInterfaceName": vpc_interface_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    server_hostname: str,
    bucket_name: str,
    agent_arns: List,
    server_port: int = None,
    server_protocol: str = None,
    subdirectory: str = None,
    access_key: str = None,
    secret_key: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an endpoint for a self-managed object storage bucket. For more information about self-managed object storage locations, see Creating a location for object storage.

    Args:
        server_hostname(str): The name of the self-managed object storage server. This value is the IP address or Domain Name Service (DNS) name of the object storage server. An agent uses this host name to mount the object storage server in a network. .
        server_port(int, optional): The port that your self-managed object storage server accepts inbound network traffic on. The server port is set by default to TCP 80 (HTTP) or TCP 443 (HTTPS). You can specify a custom port if your self-managed object storage server requires one. Defaults to None.
        server_protocol(str, optional): The protocol that the object storage server uses to communicate. Valid values are HTTP or HTTPS. Defaults to None.
        subdirectory(str, optional): The subdirectory in the self-managed object storage server that is used to read data from. Defaults to None.
        bucket_name(str): The bucket on the self-managed object storage server that is used to read data from.
        access_key(str, optional): Optional. The access key is used if credentials are required to access the self-managed object storage server. If your object storage requires a user name and password to authenticate, use AccessKey and SecretKey to provide the user name and password, respectively. Defaults to None.
        secret_key(str, optional): Optional. The secret key is used if credentials are required to access the self-managed object storage server. If your object storage requires a user name and password to authenticate, use AccessKey and SecretKey to provide the user name and password, respectively. Defaults to None.
        agent_arns(List): The Amazon Resource Name (ARN) of the agents associated with the self-managed object storage server location.
        tags(List, optional): The key-value pair that represents the tag that you want to add to the location. The value can be an empty string. We recommend using tags to name your resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.object_storage.create(
                ctx, server_hostname=value, bucket_name=value, agent_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.object_storage.create server_hostname=value, bucket_name=value, agent_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="create_location_object_storage",
        op_kwargs={
            "ServerHostname": server_hostname,
            "ServerPort": server_port,
            "ServerProtocol": server_protocol,
            "Subdirectory": subdirectory,
            "BucketName": bucket_name,
            "AccessKey": access_key,
            "SecretKey": secret_key,
            "AgentArns": agent_arns,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, location_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata about a self-managed object storage server location. For more information about self-managed object storage locations, see Creating a location for object storage.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the self-managed object storage server location that was described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.object_storage.describe(
                ctx, location_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.object_storage.describe location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="describe_location_object_storage",
        op_kwargs={"LocationArn": location_arn},
    )


async def update(
    hub,
    ctx,
    location_arn: str,
    server_port: int = None,
    server_protocol: str = None,
    subdirectory: str = None,
    access_key: str = None,
    secret_key: str = None,
    agent_arns: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates some of the parameters of a previously created location for self-managed object storage server access. For information about creating a self-managed object storage location, see Creating a location for object storage.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the self-managed object storage server location to be updated.
        server_port(int, optional): The port that your self-managed object storage server accepts inbound network traffic on. The server port is set by default to TCP 80 (HTTP) or TCP 443 (HTTPS). You can specify a custom port if your self-managed object storage server requires one. Defaults to None.
        server_protocol(str, optional): The protocol that the object storage server uses to communicate. Valid values are HTTP or HTTPS. Defaults to None.
        subdirectory(str, optional): The subdirectory in the self-managed object storage server that is used to read data from. Defaults to None.
        access_key(str, optional): Optional. The access key is used if credentials are required to access the self-managed object storage server. If your object storage requires a user name and password to authenticate, use AccessKey and SecretKey to provide the user name and password, respectively. Defaults to None.
        secret_key(str, optional): Optional. The secret key is used if credentials are required to access the self-managed object storage server. If your object storage requires a user name and password to authenticate, use AccessKey and SecretKey to provide the user name and password, respectively. Defaults to None.
        agent_arns(List, optional): The Amazon Resource Name (ARN) of the agents associated with the self-managed object storage server location. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.object_storage.update(ctx, location_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.object_storage.update location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="update_location_object_storage",
        op_kwargs={
            "LocationArn": location_arn,
            "ServerPort": server_port,
            "ServerProtocol": server_protocol,
            "Subdirectory": subdirectory,
            "AccessKey": access_key,
            "SecretKey": secret_key,
            "AgentArns": agent_arns,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    network_profile_name: str,
    ssid: str,
    security_type: str,
    client_request_token: str,
    description: str = None,
    eap_method: str = None,
    current_password: str = None,
    next_password: str = None,
    certificate_authority_arn: str = None,
    trust_anchors: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a network profile with the specified details.

    Args:
        network_profile_name(str): The name of the network profile associated with a device.
        description(str, optional): Detailed information about a device's network profile. Defaults to None.
        ssid(str): The SSID of the Wi-Fi network.
        security_type(str): The security type of the Wi-Fi network. This can be WPA2_ENTERPRISE, WPA2_PSK, WPA_PSK, WEP, or OPEN.
        eap_method(str, optional): The authentication standard that is used in the EAP framework. Currently, EAP_TLS is supported. Defaults to None.
        current_password(str, optional): The current password of the Wi-Fi network. Defaults to None.
        next_password(str, optional): The next, or subsequent, password of the Wi-Fi network. This password is asynchronously transmitted to the device and is used when the password of the network changes to NextPassword. . Defaults to None.
        certificate_authority_arn(str, optional): The ARN of the Private Certificate Authority (PCA) created in AWS Certificate Manager (ACM). This is used to issue certificates to the devices. . Defaults to None.
        trust_anchors(List, optional): The root certificates of your authentication server that is installed on your devices and used to trust your authentication server during EAP negotiation. . Defaults to None.
        client_request_token(str): A unique, user-specified identifier for the request that ensures idempotency.
        tags(List, optional): The tags to be added to the specified resource. Do not provide system tags. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.network_profile.create(
                ctx,
                network_profile_name=value,
                ssid=value,
                security_type=value,
                client_request_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.network_profile.create network_profile_name=value, ssid=value, security_type=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_network_profile",
        op_kwargs={
            "NetworkProfileName": network_profile_name,
            "Description": description,
            "Ssid": ssid,
            "SecurityType": security_type,
            "EapMethod": eap_method,
            "CurrentPassword": current_password,
            "NextPassword": next_password,
            "CertificateAuthorityArn": certificate_authority_arn,
            "TrustAnchors": trust_anchors,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, network_profile_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a network profile by the network profile ARN.

    Args:
        network_profile_arn(str): The ARN of the network profile associated with a device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.network_profile.delete(
                ctx, network_profile_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.network_profile.delete network_profile_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_network_profile",
        op_kwargs={"NetworkProfileArn": network_profile_arn},
    )


async def get(hub, ctx, network_profile_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the network profile details by the network profile ARN.

    Args:
        network_profile_arn(str): The ARN of the network profile associated with a device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.network_profile.get(
                ctx, network_profile_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.network_profile.get network_profile_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_network_profile",
        op_kwargs={"NetworkProfileArn": network_profile_arn},
    )


async def search(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
    sort_criteria: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches network profiles and lists the ones that meet a set of filter and sort criteria.

    Args:
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. . Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. . Defaults to None.
        filters(List, optional): The filters to use to list a specified set of network profiles. Valid filters are NetworkProfileName, Ssid, and SecurityType. Defaults to None.
        sort_criteria(List, optional): The sort order to use to list the specified set of network profiles. Valid sort criteria includes NetworkProfileName, Ssid, and SecurityType. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.network_profile.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.network_profile.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="search_network_profiles",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
            "SortCriteria": sort_criteria,
        },
    )


async def update(
    hub,
    ctx,
    network_profile_arn: str,
    network_profile_name: str = None,
    description: str = None,
    current_password: str = None,
    next_password: str = None,
    certificate_authority_arn: str = None,
    trust_anchors: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a network profile by the network profile ARN.

    Args:
        network_profile_arn(str): The ARN of the network profile associated with a device.
        network_profile_name(str, optional): The name of the network profile associated with a device. Defaults to None.
        description(str, optional): Detailed information about a device's network profile. Defaults to None.
        current_password(str, optional): The current password of the Wi-Fi network. Defaults to None.
        next_password(str, optional): The next, or subsequent, password of the Wi-Fi network. This password is asynchronously transmitted to the device and is used when the password of the network changes to NextPassword. . Defaults to None.
        certificate_authority_arn(str, optional): The ARN of the Private Certificate Authority (PCA) created in AWS Certificate Manager (ACM). This is used to issue certificates to the devices. . Defaults to None.
        trust_anchors(List, optional): The root certificate(s) of your authentication server that will be installed on your devices and used to trust your authentication server during EAP negotiation. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.network_profile.update(
                ctx, network_profile_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.network_profile.update network_profile_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_network_profile",
        op_kwargs={
            "NetworkProfileArn": network_profile_arn,
            "NetworkProfileName": network_profile_name,
            "Description": description,
            "CurrentPassword": current_password,
            "NextPassword": next_password,
            "CertificateAuthorityArn": certificate_authority_arn,
            "TrustAnchors": trust_anchors,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    alarm_model_name: str,
    role_arn: str,
    alarm_rule: Dict,
    alarm_model_description: str = None,
    tags: List = None,
    key: str = None,
    severity: int = None,
    alarm_notification: Dict = None,
    alarm_event_actions: Dict = None,
    alarm_capabilities: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an alarm model to monitor an AWS IoT Events input attribute. You can use the alarm to get notified when the value is outside a specified range. For more information, see Create an alarm model in the AWS IoT Events Developer Guide.

    Args:
        alarm_model_name(str): A unique name that helps you identify the alarm model. You can't change this name after you create the alarm model.
        alarm_model_description(str, optional): A description that tells you what the alarm model detects. Defaults to None.
        role_arn(str): The ARN of the IAM role that allows the alarm to perform actions and access AWS resources. For more information, see Amazon Resource Names (ARNs) in the AWS General Reference.
        tags(List, optional): A list of key-value pairs that contain metadata for the alarm model. The tags help you manage the alarm model. For more information, see Tagging your AWS IoT Events resources in the AWS IoT Events Developer Guide. You can create up to 50 tags for one alarm model. Defaults to None.
        key(str, optional): An input attribute used as a key to create an alarm. AWS IoT Events routes inputs associated with this key to the alarm. Defaults to None.
        severity(int, optional): A non-negative integer that reflects the severity level of the alarm. Defaults to None.
        alarm_rule(Dict): Defines when your alarm is invoked.
        alarm_notification(Dict, optional): Contains information about one or more notification actions. Defaults to None.
        alarm_event_actions(Dict, optional): Contains information about one or more alarm actions. Defaults to None.
        alarm_capabilities(Dict, optional): Contains the configuration information of alarm state changes. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.alarm_model.init.create(
                ctx, alarm_model_name=value, role_arn=value, alarm_rule=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.alarm_model.init.create alarm_model_name=value, role_arn=value, alarm_rule=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="create_alarm_model",
        op_kwargs={
            "alarmModelName": alarm_model_name,
            "alarmModelDescription": alarm_model_description,
            "roleArn": role_arn,
            "tags": tags,
            "key": key,
            "severity": severity,
            "alarmRule": alarm_rule,
            "alarmNotification": alarm_notification,
            "alarmEventActions": alarm_event_actions,
            "alarmCapabilities": alarm_capabilities,
        },
    )


async def delete(hub, ctx, alarm_model_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an alarm model. Any alarm instances that were created based on this alarm model are also deleted. This action can't be undone.

    Args:
        alarm_model_name(str): The name of the alarm model.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.alarm_model.init.delete(ctx, alarm_model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.alarm_model.init.delete alarm_model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="delete_alarm_model",
        op_kwargs={"alarmModelName": alarm_model_name},
    )


async def describe(
    hub, ctx, alarm_model_name: str, alarm_model_version: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an alarm model. If you don't specify a value for the alarmModelVersion parameter, the latest version is returned.

    Args:
        alarm_model_name(str): The name of the alarm model.
        alarm_model_version(str, optional): The version of the alarm model. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.alarm_model.init.describe(ctx, alarm_model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.alarm_model.init.describe alarm_model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="describe_alarm_model",
        op_kwargs={
            "alarmModelName": alarm_model_name,
            "alarmModelVersion": alarm_model_version,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the alarm models that you created. The operation returns only the metadata associated with each alarm model.

    Args:
        next_token(str, optional): The token that you can use to return the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.alarm_model.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.alarm_model.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="list_alarm_models",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    alarm_model_name: str,
    role_arn: str,
    alarm_rule: Dict,
    alarm_model_description: str = None,
    severity: int = None,
    alarm_notification: Dict = None,
    alarm_event_actions: Dict = None,
    alarm_capabilities: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an alarm model. Any alarms that were created based on the previous version are deleted and then created again as new data arrives.

    Args:
        alarm_model_name(str): The name of the alarm model.
        alarm_model_description(str, optional): The description of the alarm model. Defaults to None.
        role_arn(str): The ARN of the IAM role that allows the alarm to perform actions and access AWS resources. For more information, see Amazon Resource Names (ARNs) in the AWS General Reference.
        severity(int, optional): A non-negative integer that reflects the severity level of the alarm. Defaults to None.
        alarm_rule(Dict): Defines when your alarm is invoked.
        alarm_notification(Dict, optional): Contains information about one or more notification actions. Defaults to None.
        alarm_event_actions(Dict, optional): Contains information about one or more alarm actions. Defaults to None.
        alarm_capabilities(Dict, optional): Contains the configuration information of alarm state changes. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.alarm_model.init.update(
                ctx, alarm_model_name=value, role_arn=value, alarm_rule=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.alarm_model.init.update alarm_model_name=value, role_arn=value, alarm_rule=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="update_alarm_model",
        op_kwargs={
            "alarmModelName": alarm_model_name,
            "alarmModelDescription": alarm_model_description,
            "roleArn": role_arn,
            "severity": severity,
            "alarmRule": alarm_rule,
            "alarmNotification": alarm_notification,
            "alarmEventActions": alarm_event_actions,
            "alarmCapabilities": alarm_capabilities,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    The GetAccountBalance operation retrieves the Prepaid HITs balance in your Amazon Mechanical Turk account if you are a Prepaid Requester. Alternatively, this operation will retrieve the remaining available AWS Billing usage if you have enabled AWS Billing. Note: If you have enabled AWS Billing and still have a remaining Prepaid HITs balance, this balance can be viewed on the My Account page in the Requester console.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.account_balance.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.account_balance.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="mturk", operation="get_account_balance", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> None:
    r"""
        **Autogenerated function**


        Adds tags to the specified MSK resource.


        Args:
            resource_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the resource that's associated with the tags.
    .
            tags(Dict):
    The key-value pair for the resource tag.
    .
        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.resource.tag(ctx, resource_arn=value, tags=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
        **Autogenerated function**


        Removes the tags associated with the keys that are provided in the query.


        Args:
            resource_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the resource that's associated with the tags.
    .
            tag_keys(List):
    Tag keys must be unique for a given cluster. In addition, the following restrictions apply:


    Each tag key must be unique. If you add a tag with a key that's already in
                      use, your new tag overwrites the existing key-value pair.


    You can't start a tag key with aws: because this prefix is reserved for use
                      by  AWS.  AWS creates tags that begin with this prefix on your behalf, but
                      you can't edit or delete them.


    Tag keys must be between 1 and 128 Unicode characters in length.


    Tag keys must consist of the following characters: Unicode letters, digits,
                      white space, and the following special characters: _ . / = + -
                         @.


    .
        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.resource.untag(ctx, resource_arn=value, tag_keys=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def restore(
    hub,
    ctx,
    target_db_instance_identifier: str,
    source_db_instance_identifier: str = None,
    restore_time: str = None,
    use_latest_restorable_time: bool = None,
    db_instance_class: str = None,
    port: int = None,
    availability_zone: str = None,
    db_subnet_group_name: str = None,
    multi_az: bool = None,
    publicly_accessible: bool = None,
    auto_minor_version_upgrade: bool = None,
    license_model: str = None,
    db_name: str = None,
    engine: str = None,
    iops: int = None,
    option_group_name: str = None,
    copy_tags_to_snapshot: bool = None,
    tags: List = None,
    storage_type: str = None,
    tde_credential_arn: str = None,
    tde_credential_password: str = None,
    vpc_security_group_ids: List = None,
    domain: str = None,
    domain_iam_role_name: str = None,
    enable_iam_database_authentication: bool = None,
    enable_cloudwatch_logs_exports: List = None,
    processor_features: List = None,
    use_default_processor_features: bool = None,
    db_parameter_group_name: str = None,
    deletion_protection: bool = None,
    source_dbi_resource_id: str = None,
    max_allocated_storage: int = None,
    source_db_instance_automated_backups_arn: str = None,
    enable_customer_owned_ip: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Restores a DB instance to an arbitrary point in time. You can restore to any point in time before the time identified by the LatestRestorableTime property. You can restore to a point up to the number of days specified by the BackupRetentionPeriod property. The target database is created with most of the original configuration, but in a system-selected Availability Zone, with the default security group, the default subnet group, and the default DB parameter group. By default, the new DB instance is created as a single-AZ deployment except when the instance is a SQL Server instance that has an option group that is associated with mirroring; in this case, the instance becomes a mirrored deployment and not a single-AZ deployment.  This command doesn't apply to Aurora MySQL and Aurora PostgreSQL. For Aurora, use RestoreDBClusterToPointInTime.

    Args:
        source_db_instance_identifier(str, optional): The identifier of the source DB instance from which to restore. Constraints:   Must match the identifier of an existing DB instance.  . Defaults to None.
        target_db_instance_identifier(str): The name of the new DB instance to be created. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens  .
        restore_time(str, optional): The date and time to restore from. Valid Values: Value must be a time in Universal Coordinated Time (UTC) format Constraints:   Must be before the latest restorable time for the DB instance   Can't be specified if the UseLatestRestorableTime parameter is enabled   Example: 2009-09-07T23:45:00Z . Defaults to None.
        use_latest_restorable_time(bool, optional):  A value that indicates whether the DB instance is restored from the latest backup time. By default, the DB instance isn't restored from the latest backup time.  Constraints: Can't be specified if the RestoreTime parameter is provided. Defaults to None.
        db_instance_class(str, optional): The compute and memory capacity of the Amazon RDS DB instance, for example, db.m4.large. Not all DB instance classes are available in all Amazon Web Services Regions, or for all database engines. For the full list of DB instance classes, and availability for your engine, see DB Instance Class in the Amazon RDS User Guide.  Default: The same DBInstanceClass as the original DB instance. Defaults to None.
        port(int, optional): The port number on which the database accepts connections. Constraints: Value must be 1150-65535  Default: The same port as the original DB instance. Defaults to None.
        availability_zone(str, optional): The Availability Zone (AZ) where the DB instance will be created. Default: A random, system-chosen Availability Zone. Constraint: You can't specify the AvailabilityZone parameter if the DB instance is a Multi-AZ deployment. Example: us-east-1a . Defaults to None.
        db_subnet_group_name(str, optional): The DB subnet group name to use for the new instance. Constraints: If supplied, must match the name of an existing DBSubnetGroup. Example: mySubnetgroup . Defaults to None.
        multi_az(bool, optional): A value that indicates whether the DB instance is a Multi-AZ deployment. Constraint: You can't specify the AvailabilityZone parameter if the DB instance is a Multi-AZ deployment. Defaults to None.
        publicly_accessible(bool, optional): A value that indicates whether the DB instance is publicly accessible. When the DB instance is publicly accessible, its DNS endpoint resolves to the private IP address from within the DB instance's VPC, and to the public IP address from outside of the DB instance's VPC. Access to the DB instance is ultimately controlled by the security group it uses, and that public access is not permitted if the security group assigned to the DB instance doesn't permit it. When the DB instance isn't publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address. For more information, see CreateDBInstance. Defaults to None.
        auto_minor_version_upgrade(bool, optional): A value that indicates whether minor version upgrades are applied automatically to the DB instance during the maintenance window. Defaults to None.
        license_model(str, optional): License model information for the restored DB instance. Default: Same as source.  Valid values: license-included | bring-your-own-license | general-public-license . Defaults to None.
        db_name(str, optional): The database name for the restored DB instance.  This parameter isn't used for the MySQL or MariaDB engines. . Defaults to None.
        engine(str, optional): The database engine to use for the new instance. Default: The same as source Constraint: Must be compatible with the engine of the source Valid Values:    mariadb     mysql     oracle-ee     oracle-ee-cdb     oracle-se2     oracle-se2-cdb     postgres     sqlserver-ee     sqlserver-se     sqlserver-ex     sqlserver-web   . Defaults to None.
        iops(int, optional): The amount of Provisioned IOPS (input/output operations per second) to be initially allocated for the DB instance. Constraints: Must be an integer greater than 1000.  SQL Server  Setting the IOPS value for the SQL Server database engine isn't supported. Defaults to None.
        option_group_name(str, optional): The name of the option group to be used for the restored DB instance. Permanent options, such as the TDE option for Oracle Advanced Security TDE, can't be removed from an option group, and that option group can't be removed from a DB instance once it is associated with a DB instance. Defaults to None.
        copy_tags_to_snapshot(bool, optional): A value that indicates whether to copy all tags from the restored DB instance to snapshots of the DB instance. By default, tags are not copied. Defaults to None.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.
        storage_type(str, optional): Specifies the storage type to be associated with the DB instance.  Valid values: standard | gp2 | io1   If you specify io1, you must also include a value for the Iops parameter.   Default: io1 if the Iops parameter is specified, otherwise gp2 . Defaults to None.
        tde_credential_arn(str, optional): The ARN from the key store with which to associate the instance for TDE encryption. Defaults to None.
        tde_credential_password(str, optional): The password for the given ARN from the key store in order to access the device. Defaults to None.
        vpc_security_group_ids(List, optional):  A list of EC2 VPC security groups to associate with this DB instance.   Default: The default EC2 VPC security group for the DB subnet group's VPC. . Defaults to None.
        domain(str, optional): Specify the Active Directory directory ID to restore the DB instance in. The domain must be created prior to this operation. Currently, only MySQL, Microsoft SQL Server, Oracle, and PostgreSQL DB instances can be created in an Active Directory Domain. For more information, see  Kerberos Authentication in the Amazon RDS User Guide. Defaults to None.
        domain_iam_role_name(str, optional): Specify the name of the IAM role to be used when making API calls to the Directory Service. Defaults to None.
        enable_iam_database_authentication(bool, optional): A value that indicates whether to enable mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts. By default, mapping is disabled. For more information about IAM database authentication, see  IAM Database Authentication for MySQL and PostgreSQL in the Amazon RDS User Guide. . Defaults to None.
        enable_cloudwatch_logs_exports(List, optional): The list of logs that the restored DB instance is to export to CloudWatch Logs. The values in the list depend on the DB engine being used. For more information, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon RDS User Guide. Defaults to None.
        processor_features(List, optional): The number of CPU cores and the number of threads per core for the DB instance class of the DB instance. Defaults to None.
        use_default_processor_features(bool, optional): A value that indicates whether the DB instance class of the DB instance uses its default processor features. Defaults to None.
        db_parameter_group_name(str, optional): The name of the DB parameter group to associate with this DB instance. If you do not specify a value for DBParameterGroupName, then the default DBParameterGroup for the specified DB engine is used. Constraints:   If supplied, must match the name of an existing DBParameterGroup.   Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter.   Can't end with a hyphen or contain two consecutive hyphens.  . Defaults to None.
        deletion_protection(bool, optional): A value that indicates whether the DB instance has deletion protection enabled. The database can't be deleted when deletion protection is enabled. By default, deletion protection is disabled. For more information, see  Deleting a DB Instance. . Defaults to None.
        source_dbi_resource_id(str, optional): The resource ID of the source DB instance from which to restore. Defaults to None.
        max_allocated_storage(int, optional): The upper limit to which Amazon RDS can automatically scale the storage of the DB instance. For more information about this setting, including limitations that apply to it, see  Managing capacity automatically with Amazon RDS storage autoscaling in the Amazon RDS User Guide. Defaults to None.
        source_db_instance_automated_backups_arn(str, optional): The Amazon Resource Name (ARN) of the replicated automated backups from which to restore, for example, arn:aws:rds:useast-1:123456789012:auto-backup:ab-L2IJCEXJP7XQ7HOJ4SIEXAMPLE. Defaults to None.
        enable_customer_owned_ip(bool, optional): A value that indicates whether to enable a customer-owned IP address (CoIP) for an RDS on Outposts DB instance. A CoIP provides local or external connectivity to resources in your Outpost subnets through your on-premises network. For some use cases, a CoIP can provide lower latency for connections to the DB instance from outside of its virtual private cloud (VPC) on your local network. For more information about RDS on Outposts, see Working with Amazon RDS on Amazon Web Services Outposts in the Amazon RDS User Guide. For more information about CoIPs, see Customer-owned IP addresses in the Amazon Web Services Outposts User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.instance.to_point_in_time.restore(
                ctx, target_db_instance_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.instance.to_point_in_time.restore target_db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="restore_db_instance_to_point_in_time",
        op_kwargs={
            "SourceDBInstanceIdentifier": source_db_instance_identifier,
            "TargetDBInstanceIdentifier": target_db_instance_identifier,
            "RestoreTime": restore_time,
            "UseLatestRestorableTime": use_latest_restorable_time,
            "DBInstanceClass": db_instance_class,
            "Port": port,
            "AvailabilityZone": availability_zone,
            "DBSubnetGroupName": db_subnet_group_name,
            "MultiAZ": multi_az,
            "PubliclyAccessible": publicly_accessible,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "LicenseModel": license_model,
            "DBName": db_name,
            "Engine": engine,
            "Iops": iops,
            "OptionGroupName": option_group_name,
            "CopyTagsToSnapshot": copy_tags_to_snapshot,
            "Tags": tags,
            "StorageType": storage_type,
            "TdeCredentialArn": tde_credential_arn,
            "TdeCredentialPassword": tde_credential_password,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "Domain": domain,
            "DomainIAMRoleName": domain_iam_role_name,
            "EnableIAMDatabaseAuthentication": enable_iam_database_authentication,
            "EnableCloudwatchLogsExports": enable_cloudwatch_logs_exports,
            "ProcessorFeatures": processor_features,
            "UseDefaultProcessorFeatures": use_default_processor_features,
            "DBParameterGroupName": db_parameter_group_name,
            "DeletionProtection": deletion_protection,
            "SourceDbiResourceId": source_dbi_resource_id,
            "MaxAllocatedStorage": max_allocated_storage,
            "SourceDBInstanceAutomatedBackupsArn": source_db_instance_automated_backups_arn,
            "EnableCustomerOwnedIp": enable_customer_owned_ip,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Given a device ID, returns the invokable methods associated with the device.

    Args:
        device_id(str): The unique identifier of the device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_device.device.method.get_all(ctx, device_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_device.device.method.get_all device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="get_device_methods",
        op_kwargs={"DeviceId": device_id},
    )


async def invoke(
    hub,
    ctx,
    device_id: str,
    device_method: Dict = None,
    device_method_parameters: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Given a device ID, issues a request to invoke a named device method (with possible
     parameters). See the "Example POST" code snippet below.

    Args:
        device_id(str): The unique identifier of the device.
        device_method(Dict, optional): The device method to invoke. Defaults to None.
        device_method_parameters(str, optional): A JSON encoded string containing the device method request parameters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_device.device.method.invoke(ctx, device_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_device.device.method.invoke device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="invoke_device_method",
        op_kwargs={
            "DeviceId": device_id,
            "DeviceMethod": device_method,
            "DeviceMethodParameters": device_method_parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    voice_connector_id: str,
    participant_phone_numbers: List,
    capabilities: List,
    name: str = None,
    expiry_minutes: int = None,
    number_selection_behavior: str = None,
    geo_match_level: str = None,
    geo_match_params: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a proxy session on the specified Amazon Chime Voice Connector for the specified participant phone numbers.

    Args:
        voice_connector_id(str): The Amazon Chime voice connector ID.
        participant_phone_numbers(List): The participant phone numbers.
        name(str, optional): The name of the proxy session. Defaults to None.
        expiry_minutes(int, optional): The number of minutes allowed for the proxy session. Defaults to None.
        capabilities(List): The proxy session capabilities.
        number_selection_behavior(str, optional): The preference for proxy phone number reuse, or stickiness, between the same participants across sessions. Defaults to None.
        geo_match_level(str, optional): The preference for matching the country or area code of the proxy phone number with that of the first participant. Defaults to None.
        geo_match_params(Dict, optional): The country and area code for the proxy phone number. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.proxy_session.create(
                ctx, voice_connector_id=value, participant_phone_numbers=value, capabilities=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.proxy_session.create voice_connector_id=value, participant_phone_numbers=value, capabilities=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_proxy_session",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "ParticipantPhoneNumbers": participant_phone_numbers,
            "Name": name,
            "ExpiryMinutes": expiry_minutes,
            "Capabilities": capabilities,
            "NumberSelectionBehavior": number_selection_behavior,
            "GeoMatchLevel": geo_match_level,
            "GeoMatchParams": geo_match_params,
        },
    )


async def delete(hub, ctx, voice_connector_id: str, proxy_session_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified proxy session from the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime voice connector ID.
        proxy_session_id(str): The proxy session ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.proxy_session.delete(
                ctx, voice_connector_id=value, proxy_session_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.proxy_session.delete voice_connector_id=value, proxy_session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_proxy_session",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "ProxySessionId": proxy_session_id,
        },
    )


async def get(hub, ctx, voice_connector_id: str, proxy_session_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the specified proxy session details for the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime voice connector ID.
        proxy_session_id(str): The proxy session ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.proxy_session.get(
                ctx, voice_connector_id=value, proxy_session_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.proxy_session.get voice_connector_id=value, proxy_session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_proxy_session",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "ProxySessionId": proxy_session_id,
        },
    )


async def list_all(
    hub,
    ctx,
    voice_connector_id: str,
    status: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the proxy sessions for the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime voice connector ID.
        status(str, optional): The proxy session status. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.proxy_session.list_all(ctx, voice_connector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.proxy_session.list_all voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_proxy_sessions",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "Status": status,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    voice_connector_id: str,
    proxy_session_id: str,
    capabilities: List,
    expiry_minutes: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified proxy session details, such as voice or SMS capabilities.

    Args:
        voice_connector_id(str): The Amazon Chime voice connector ID.
        proxy_session_id(str): The proxy session ID.
        capabilities(List): The proxy session capabilities.
        expiry_minutes(int, optional): The number of minutes allowed for the proxy session. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.proxy_session.update(
                ctx, voice_connector_id=value, proxy_session_id=value, capabilities=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.proxy_session.update voice_connector_id=value, proxy_session_id=value, capabilities=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_proxy_session",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "ProxySessionId": proxy_session_id,
            "Capabilities": capabilities,
            "ExpiryMinutes": expiry_minutes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    edge_packaging_job_name: str,
    compilation_job_name: str,
    model_name: str,
    model_version: str,
    role_arn: str,
    output_config: Dict,
    resource_key: str = None,
    tags: List = None,
) -> None:
    r"""
    **Autogenerated function**

    Starts a SageMaker Edge Manager model packaging job. Edge Manager will use the model artifacts from the Amazon Simple Storage Service bucket that you specify. After the model has been packaged, Amazon SageMaker saves the resulting artifacts to an S3 bucket that you specify.

    Args:
        edge_packaging_job_name(str): The name of the edge packaging job.
        compilation_job_name(str): The name of the SageMaker Neo compilation job that will be used to locate model artifacts for packaging.
        model_name(str): The name of the model.
        model_version(str): The version of the model.
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to download and upload the model, and to contact SageMaker Neo.
        output_config(Dict): Provides information about the output location for the packaged model.
        resource_key(str, optional): The CMK to use when encrypting the EBS volume the edge packaging job runs on. Defaults to None.
        tags(List, optional): Creates tags for the packaging job. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.edge_packaging_job.create(
                ctx,
                edge_packaging_job_name=value,
                compilation_job_name=value,
                model_name=value,
                model_version=value,
                role_arn=value,
                output_config=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.edge_packaging_job.create edge_packaging_job_name=value, compilation_job_name=value, model_name=value, model_version=value, role_arn=value, output_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_edge_packaging_job",
        op_kwargs={
            "EdgePackagingJobName": edge_packaging_job_name,
            "CompilationJobName": compilation_job_name,
            "ModelName": model_name,
            "ModelVersion": model_version,
            "RoleArn": role_arn,
            "OutputConfig": output_config,
            "ResourceKey": resource_key,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, edge_packaging_job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    A description of edge packaging jobs.

    Args:
        edge_packaging_job_name(str): The name of the edge packaging job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.edge_packaging_job.describe(
                ctx, edge_packaging_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.edge_packaging_job.describe edge_packaging_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_edge_packaging_job",
        op_kwargs={"EdgePackagingJobName": edge_packaging_job_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    creation_time_after: str = None,
    creation_time_before: str = None,
    last_modified_time_after: str = None,
    last_modified_time_before: str = None,
    name_contains: str = None,
    model_name_contains: str = None,
    status_equals: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of edge packaging jobs.

    Args:
        next_token(str, optional): The response from the last list when returning a list large enough to need tokening. Defaults to None.
        max_results(int, optional): Maximum number of results to select. Defaults to None.
        creation_time_after(str, optional): Select jobs where the job was created after specified time. Defaults to None.
        creation_time_before(str, optional): Select jobs where the job was created before specified time. Defaults to None.
        last_modified_time_after(str, optional): Select jobs where the job was updated after specified time. Defaults to None.
        last_modified_time_before(str, optional): Select jobs where the job was updated before specified time. Defaults to None.
        name_contains(str, optional): Filter for jobs containing this name in their packaging job name. Defaults to None.
        model_name_contains(str, optional): Filter for jobs where the model name contains this string. Defaults to None.
        status_equals(str, optional): The job status to filter for. Defaults to None.
        sort_by(str, optional): Use to specify what column to sort by. Defaults to None.
        sort_order(str, optional): What direction to sort by. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.edge_packaging_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.edge_packaging_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_edge_packaging_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "NameContains": name_contains,
            "ModelNameContains": model_name_contains,
            "StatusEquals": status_equals,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )


async def stop(hub, ctx, edge_packaging_job_name: str) -> None:
    r"""
    **Autogenerated function**

    Request to stop an edge packaging job.

    Args:
        edge_packaging_job_name(str): The name of the edge packaging job.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.edge_packaging_job.stop(
                ctx, edge_packaging_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.edge_packaging_job.stop edge_packaging_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_edge_packaging_job",
        op_kwargs={"EdgePackagingJobName": edge_packaging_job_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "to_permission_set"


async def attach(
    hub, ctx, instance_arn: str, permission_set_arn: str, managed_policy_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches an IAM managed policy ARN to a permission set.  If the permission set is already referenced by one or more account assignments, you will need to call  ProvisionPermissionSet  after this operation. Calling ProvisionPermissionSet applies the corresponding IAM policy updates to all assigned accounts.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        permission_set_arn(str): The ARN of the PermissionSet that the managed policy should be attached to.
        managed_policy_arn(str): The IAM managed policy ARN to be attached to a permission set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.managed_policy.to_permission_set_.attach(
                ctx, instance_arn=value, permission_set_arn=value, managed_policy_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.managed_policy.to_permission_set.attach instance_arn=value, permission_set_arn=value, managed_policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="attach_managed_policy_to_permission_set",
        op_kwargs={
            "InstanceArn": instance_arn,
            "PermissionSetArn": permission_set_arn,
            "ManagedPolicyArn": managed_policy_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, user_name: str, ssh_public_key_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified SSH public key. The SSH public key deleted by this operation is used only for authenticating the associated IAM user to an CodeCommit repository. For more information about using SSH keys to authenticate to an CodeCommit repository, see Set up CodeCommit for SSH connections in the CodeCommit User Guide.

    Args:
        user_name(str): The name of the IAM user associated with the SSH public key. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        ssh_public_key_id(str): The unique identifier for the SSH public key. This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.ssh_public_key.delete(
                ctx, user_name=value, ssh_public_key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.ssh_public_key.delete user_name=value, ssh_public_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_ssh_public_key",
        op_kwargs={"UserName": user_name, "SSHPublicKeyId": ssh_public_key_id},
    )


async def get(hub, ctx, user_name: str, ssh_public_key_id: str, encoding: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified SSH public key, including metadata about the key. The SSH public key retrieved by this operation is used only for authenticating the associated IAM user to an CodeCommit repository. For more information about using SSH keys to authenticate to an CodeCommit repository, see Set up CodeCommit for SSH connections in the CodeCommit User Guide.

    Args:
        user_name(str): The name of the IAM user associated with the SSH public key. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        ssh_public_key_id(str): The unique identifier for the SSH public key. This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.
        encoding(str): Specifies the public key encoding format to use in the response. To retrieve the public key in ssh-rsa format, use SSH. To retrieve the public key in PEM format, use PEM.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.ssh_public_key.get(
                ctx, user_name=value, ssh_public_key_id=value, encoding=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.ssh_public_key.get user_name=value, ssh_public_key_id=value, encoding=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_ssh_public_key",
        op_kwargs={
            "UserName": user_name,
            "SSHPublicKeyId": ssh_public_key_id,
            "Encoding": encoding,
        },
    )


async def list_all(
    hub, ctx, user_name: str = None, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the SSH public keys associated with the specified IAM user. If none exists, the operation returns an empty list. The SSH public keys returned by this operation are used only for authenticating the IAM user to an CodeCommit repository. For more information about using SSH keys to authenticate to an CodeCommit repository, see Set up CodeCommit for SSH connections in the CodeCommit User Guide. Although each user is limited to a small number of keys, you can still paginate the results using the MaxItems and Marker parameters.

    Args:
        user_name(str, optional): The name of the IAM user to list SSH public keys for. If none is specified, the UserName field is determined implicitly based on the Amazon Web Services access key used to sign the request. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.ssh_public_key.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.ssh_public_key.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_ssh_public_keys",
        op_kwargs={"UserName": user_name, "Marker": marker, "MaxItems": max_items},
    )


async def update(hub, ctx, user_name: str, ssh_public_key_id: str, status: str) -> None:
    r"""
    **Autogenerated function**

    Sets the status of an IAM user's SSH public key to active or inactive. SSH public keys that are inactive cannot be used for authentication. This operation can be used to disable a user's SSH public key as part of a key rotation work flow. The SSH public key affected by this operation is used only for authenticating the associated IAM user to an CodeCommit repository. For more information about using SSH keys to authenticate to an CodeCommit repository, see Set up CodeCommit for SSH connections in the CodeCommit User Guide.

    Args:
        user_name(str): The name of the IAM user associated with the SSH public key. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        ssh_public_key_id(str): The unique identifier for the SSH public key. This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.
        status(str): The status to assign to the SSH public key. Active means that the key can be used for authentication with an CodeCommit repository. Inactive means that the key cannot be used.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.ssh_public_key.update(
                ctx, user_name=value, ssh_public_key_id=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.ssh_public_key.update user_name=value, ssh_public_key_id=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_ssh_public_key",
        op_kwargs={
            "UserName": user_name,
            "SSHPublicKeyId": ssh_public_key_id,
            "Status": status,
        },
    )


async def upload(hub, ctx, user_name: str, ssh_public_key_body: str) -> Dict:
    r"""
    **Autogenerated function**

    Uploads an SSH public key and associates it with the specified IAM user. The SSH public key uploaded by this operation can be used only for authenticating the associated IAM user to an CodeCommit repository. For more information about using SSH keys to authenticate to an CodeCommit repository, see Set up CodeCommit for SSH connections in the CodeCommit User Guide.

    Args:
        user_name(str): The name of the IAM user to associate the SSH public key with. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        ssh_public_key_body(str): The SSH public key. The public key must be encoded in ssh-rsa format or PEM format. The minimum bit-length of the public key is 2048 bits. For example, you can generate a 2048-bit key, and the resulting PEM file is 1679 bytes long. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.ssh_public_key.upload(
                ctx, user_name=value, ssh_public_key_body=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.ssh_public_key.upload user_name=value, ssh_public_key_body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="upload_ssh_public_key",
        op_kwargs={"UserName": user_name, "SSHPublicKeyBody": ssh_public_key_body},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    transit_gateway_route_table_id: str,
    transit_gateway_attachment_id: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified attachment with the specified transit gateway route table. You can associate only one route table with an attachment.

    Args:
        transit_gateway_route_table_id(str): The ID of the transit gateway route table.
        transit_gateway_attachment_id(str): The ID of the attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.table.init.associate(
                ctx, transit_gateway_route_table_id=value, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.table.init.associate transit_gateway_route_table_id=value, transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="associate_transit_gateway_route_table",
        op_kwargs={
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )


async def create(
    hub,
    ctx,
    transit_gateway_id: str,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a route table for the specified transit gateway.

    Args:
        transit_gateway_id(str): The ID of the transit gateway.
        tag_specifications(List, optional): The tags to apply to the transit gateway route table. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.table.init.create(
                ctx, transit_gateway_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.table.init.create transit_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_transit_gateway_route_table",
        op_kwargs={
            "TransitGatewayId": transit_gateway_id,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, transit_gateway_route_table_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified transit gateway route table. You must disassociate the route table from any transit gateway route tables before you can delete it.

    Args:
        transit_gateway_route_table_id(str): The ID of the transit gateway route table.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.table.init.delete(
                ctx, transit_gateway_route_table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.table.init.delete transit_gateway_route_table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_transit_gateway_route_table",
        op_kwargs={
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    transit_gateway_route_table_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more transit gateway route tables. By default, all transit gateway route tables are described. Alternatively, you can filter the results.

    Args:
        transit_gateway_route_table_ids(List, optional): The IDs of the transit gateway route tables. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    default-association-route-table - Indicates whether this is the default association route table for the transit gateway (true | false).    default-propagation-route-table - Indicates whether this is the default propagation route table for the transit gateway (true | false).    state - The state of the route table (available | deleting | deleted | pending).    transit-gateway-id - The ID of the transit gateway.    transit-gateway-route-table-id - The ID of the transit gateway route table.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.table.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.table.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_transit_gateway_route_tables",
        op_kwargs={
            "TransitGatewayRouteTableIds": transit_gateway_route_table_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )


async def disassociate(
    hub,
    ctx,
    transit_gateway_route_table_id: str,
    transit_gateway_attachment_id: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a resource attachment from a transit gateway route table.

    Args:
        transit_gateway_route_table_id(str): The ID of the transit gateway route table.
        transit_gateway_attachment_id(str): The ID of the attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.table.init.disassociate(
                ctx, transit_gateway_route_table_id=value, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.table.init.disassociate transit_gateway_route_table_id=value, transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disassociate_transit_gateway_route_table",
        op_kwargs={
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables the GCM channel for an application and deletes any existing settings for the channel.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.gcm_channel.delete(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.gcm_channel.delete application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="delete_gcm_channel",
        op_kwargs={"ApplicationId": application_id},
    )


async def get(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the status and settings of the GCM channel for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.gcm_channel.get(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.gcm_channel.get application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_gcm_channel",
        op_kwargs={"ApplicationId": application_id},
    )


async def update(hub, ctx, application_id: str, gcm_channel_request: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Enables the GCM channel for an application or updates the status and settings of the GCM channel for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        gcm_channel_request(Dict): Specifies the status and settings of the GCM channel for an application. This channel enables Amazon Pinpoint to send push notifications through the Firebase Cloud Messaging (FCM), formerly Google Cloud Messaging (GCM), service.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.gcm_channel.update(
                ctx, application_id=value, gcm_channel_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.gcm_channel.update application_id=value, gcm_channel_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="update_gcm_channel",
        op_kwargs={
            "ApplicationId": application_id,
            "GCMChannelRequest": gcm_channel_request,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, repository_name: str, registry_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve catalog metadata for a repository in a public registry. This metadata is displayed publicly in the Amazon ECR Public Gallery.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repositories to be described. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The name of the repository to retrieve the catalog metadata for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.repository.catalog_data.get(
                ctx, repository_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.repository.catalog_data.get repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="get_repository_catalog_data",
        op_kwargs={"registryId": registry_id, "repositoryName": repository_name},
    )


async def put(
    hub, ctx, repository_name: str, catalog_data: Dict, registry_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates the catalog data for a repository in a public registry.

    Args:
        registry_id(str, optional): The AWS account ID associated with the public registry the repository is in. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The name of the repository to create or update the catalog data for.
        catalog_data(Dict): An object containing the catalog data for a repository. This data is publicly visible in the Amazon ECR Public Gallery.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.repository.catalog_data.put(
                ctx, repository_name=value, catalog_data=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.repository.catalog_data.put repository_name=value, catalog_data=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="put_repository_catalog_data",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "catalogData": catalog_data,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, file_system_id: str, tags: List) -> None:
    r"""
    **Autogenerated function**

     DEPRECATED - CreateTags is deprecated and not maintained. Please use the API action to create tags for EFS resources.  Creates or overwrites tags associated with a file system. Each tag is a key-value pair. If a tag key specified in the request already exists on the file system, this operation overwrites its value with the value provided in the request. If you add the Name tag to your file system, Amazon EFS returns it in the response to the DescribeFileSystems operation.  This operation requires permission for the elasticfilesystem:CreateTags action.

    Args:
        file_system_id(str): The ID of the file system whose tags you want to modify (String). This operation modifies the tags only, not the file system.
        tags(List): An array of Tag objects to add. Each Tag object is a key-value pair. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.tags.init.create(ctx, file_system_id=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.tags.init.create file_system_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="create_tags",
        op_kwargs={"FileSystemId": file_system_id, "Tags": tags},
    )


async def delete(hub, ctx, file_system_id: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

     DEPRECATED - DeleteTags is deprecated and not maintained. Please use the API action to remove tags from EFS resources.  Deletes the specified tags from a file system. If the DeleteTags request includes a tag key that doesn't exist, Amazon EFS ignores it and doesn't cause an error. For more information about tags and related restrictions, see Tag Restrictions in the AWS Billing and Cost Management User Guide. This operation requires permissions for the elasticfilesystem:DeleteTags action.

    Args:
        file_system_id(str): The ID of the file system whose tags you want to delete (String).
        tag_keys(List): A list of tag keys to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.tags.init.delete(ctx, file_system_id=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.tags.init.delete file_system_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="delete_tags",
        op_kwargs={"FileSystemId": file_system_id, "TagKeys": tag_keys},
    )


async def describe(
    hub, ctx, file_system_id: str, max_items: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     DEPRECATED - The DeleteTags action is deprecated and not maintained. Please use the API action to remove tags from EFS resources.  Returns the tags associated with a file system. The order of tags returned in the response of one DescribeTags call and the order of tags returned across the responses of a multiple-call iteration (when using pagination) is unspecified.   This operation requires permissions for the elasticfilesystem:DescribeTags action.

    Args:
        max_items(int, optional): (Optional) The maximum number of file system tags to return in the response. Currently, this number is automatically set to 100, and other values are ignored. The response is paginated at 100 per page if you have more than 100 tags. Defaults to None.
        marker(str, optional): (Optional) An opaque pagination token returned from a previous DescribeTags operation (String). If present, it specifies to continue the list from where the previous call left off. Defaults to None.
        file_system_id(str): The ID of the file system whose tag set you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.tags.init.describe(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.tags.init.describe file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="describe_tags",
        op_kwargs={
            "MaxItems": max_items,
            "Marker": marker,
            "FileSystemId": file_system_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, device_fleet_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a fleet.

    Args:
        device_fleet_name(str): The name of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.device.fleet.report.get(ctx, device_fleet_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.device.fleet.report.get device_fleet_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="get_device_fleet_report",
        op_kwargs={"DeviceFleetName": device_fleet_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    pipeline_name: str,
    pipeline_definition: str,
    client_request_token: str,
    role_arn: str,
    pipeline_display_name: str = None,
    pipeline_description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a pipeline using a JSON pipeline definition.

    Args:
        pipeline_name(str): The name of the pipeline.
        pipeline_display_name(str, optional): The display name of the pipeline. Defaults to None.
        pipeline_definition(str): The JSON pipeline definition of the pipeline.
        pipeline_description(str, optional): A description of the pipeline. Defaults to None.
        client_request_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time.
        role_arn(str): The Amazon Resource Name (ARN) of the role used by the pipeline to access and create resources.
        tags(List, optional): A list of tags to apply to the created pipeline. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.init.create(
                ctx,
                pipeline_name=value,
                pipeline_definition=value,
                client_request_token=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.init.create pipeline_name=value, pipeline_definition=value, client_request_token=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_pipeline",
        op_kwargs={
            "PipelineName": pipeline_name,
            "PipelineDisplayName": pipeline_display_name,
            "PipelineDefinition": pipeline_definition,
            "PipelineDescription": pipeline_description,
            "ClientRequestToken": client_request_token,
            "RoleArn": role_arn,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, pipeline_name: str, client_request_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a pipeline if there are no running instances of the pipeline. To delete a pipeline, you must stop all running instances of the pipeline using the StopPipelineExecution API. When you delete a pipeline, all instances of the pipeline are deleted.

    Args:
        pipeline_name(str): The name of the pipeline to delete.
        client_request_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.init.delete(
                ctx, pipeline_name=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.init.delete pipeline_name=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_pipeline",
        op_kwargs={
            "PipelineName": pipeline_name,
            "ClientRequestToken": client_request_token,
        },
    )


async def describe(hub, ctx, pipeline_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the details of a pipeline.

    Args:
        pipeline_name(str): The name of the pipeline to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.init.describe(ctx, pipeline_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.init.describe pipeline_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_pipeline",
        op_kwargs={"PipelineName": pipeline_name},
    )


async def list_all(
    hub,
    ctx,
    pipeline_name_prefix: str = None,
    created_after: str = None,
    created_before: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of pipelines.

    Args:
        pipeline_name_prefix(str, optional): The prefix of the pipeline name. Defaults to None.
        created_after(str, optional): A filter that returns the pipelines that were created after a specified time. Defaults to None.
        created_before(str, optional): A filter that returns the pipelines that were created before a specified time. Defaults to None.
        sort_by(str, optional): The field by which to sort results. The default is CreatedTime. Defaults to None.
        sort_order(str, optional): The sort order for results. Defaults to None.
        next_token(str, optional): If the result of the previous ListPipelines request was truncated, the response includes a NextToken. To retrieve the next set of pipelines, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of pipelines to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_pipelines",
        op_kwargs={
            "PipelineNamePrefix": pipeline_name_prefix,
            "CreatedAfter": created_after,
            "CreatedBefore": created_before,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    pipeline_name: str,
    pipeline_display_name: str = None,
    pipeline_definition: str = None,
    pipeline_description: str = None,
    role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a pipeline.

    Args:
        pipeline_name(str): The name of the pipeline to update.
        pipeline_display_name(str, optional): The display name of the pipeline. Defaults to None.
        pipeline_definition(str, optional): The JSON pipeline definition. Defaults to None.
        pipeline_description(str, optional): The description of the pipeline. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) that the pipeline uses to execute. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.pipeline.init.update(ctx, pipeline_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.pipeline.init.update pipeline_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_pipeline",
        op_kwargs={
            "PipelineName": pipeline_name,
            "PipelineDisplayName": pipeline_display_name,
            "PipelineDefinition": pipeline_definition,
            "PipelineDescription": pipeline_description,
            "RoleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def merge(
    hub,
    ctx,
    pull_request_id: str,
    repository_name: str,
    source_commit_id: str = None,
    conflict_detail_level: str = None,
    conflict_resolution_strategy: str = None,
    commit_message: str = None,
    author_name: str = None,
    email: str = None,
    keep_empty_folders: bool = None,
    conflict_resolution: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the three-way merge strategy. If the merge is successful, it closes the pull request.

    Args:
        pull_request_id(str): The system-generated ID of the pull request. To get this ID, use ListPullRequests.
        repository_name(str): The name of the repository where the pull request was created.
        source_commit_id(str, optional): The full commit ID of the original or updated commit in the pull request source branch. Pass this value if you want an exception thrown if the current commit ID of the tip of the source branch does not match this commit ID. Defaults to None.
        conflict_detail_level(str, optional): The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line. Defaults to None.
        conflict_resolution_strategy(str, optional): Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful. Defaults to None.
        commit_message(str, optional): The commit message to include in the commit information for the merge. Defaults to None.
        author_name(str, optional): The name of the author who created the commit. This information is used as both the author and committer for the commit. Defaults to None.
        email(str, optional): The email address of the person merging the branches. This information is used in the commit information for the merge. Defaults to None.
        keep_empty_folders(bool, optional): If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If true, a .gitkeep file is created for empty folders. The default is false. Defaults to None.
        conflict_resolution(Dict, optional): If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.by.three_way.merge(
                ctx, pull_request_id=value, repository_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.by.three_way.merge pull_request_id=value, repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="merge_pull_request_by_three_way",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "repositoryName": repository_name,
            "sourceCommitId": source_commit_id,
            "conflictDetailLevel": conflict_detail_level,
            "conflictResolutionStrategy": conflict_resolution_strategy,
            "commitMessage": commit_message,
            "authorName": author_name,
            "email": email,
            "keepEmptyFolders": keep_empty_folders,
            "conflictResolution": conflict_resolution,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    domain: str,
    repository: str,
    domain_owner: str = None,
    format_: str = None,
    namespace: str = None,
    package_prefix: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of PackageSummary objects for packages in a repository that match the request parameters.

    Args:
        domain(str):  The name of the domain that contains the repository that contains the requested list of packages. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        repository(str):  The name of the repository from which packages are to be listed. .
        format_(str, optional):  The format of the packages. The valid package types are:     npm: A Node Package Manager (npm) package.     pypi: A Python Package Index (PyPI) package.     maven: A Maven package that contains compiled code in a distributable format, such as a JAR file.   . Defaults to None.
        namespace(str, optional):  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   . Defaults to None.
        package_prefix(str, optional):  A prefix used to filter returned packages. Only packages with names that start with packagePrefix are returned. . Defaults to None.
        max_results(int, optional):  The maximum number of results to return per page. . Defaults to None.
        next_token(str, optional):  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.package.init.list_all(
                ctx, domain=value, repository=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.package.init.list_all domain=value, repository=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="list_packages",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "repository": repository,
            "format": format_,
            "namespace": namespace,
            "packagePrefix": package_prefix,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, detector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the detector. Before deleting a detector, you must first delete all detector versions and rule versions associated with the detector. When you delete a detector, Amazon Fraud Detector permanently deletes the detector and the data is no longer stored in Amazon Fraud Detector.

    Args:
        detector_id(str): The ID of the detector to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.detector.init.delete(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.detector.init.delete detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_detector",
        op_kwargs={"detectorId": detector_id},
    )


async def describe(
    hub, ctx, detector_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all versions for a specified detector.

    Args:
        detector_id(str): The detector ID.
        next_token(str, optional): The next token from the previous response. Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.detector.init.describe(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.detector.init.describe detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="describe_detector",
        op_kwargs={
            "detectorId": detector_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def get_all(
    hub, ctx, detector_id: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all detectors or a single detector if a detectorId is specified. This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetDetectorsResponse as part of your request. A null pagination token fetches the records from the beginning.

    Args:
        detector_id(str, optional): The detector ID. Defaults to None.
        next_token(str, optional): The next token for the subsequent request. Defaults to None.
        max_results(int, optional): The maximum number of objects to return for the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.detector.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.detector.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_detectors",
        op_kwargs={
            "detectorId": detector_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def put(
    hub,
    ctx,
    detector_id: str,
    event_type_name: str,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a detector.

    Args:
        detector_id(str): The detector ID. .
        description(str, optional): The description of the detector. Defaults to None.
        event_type_name(str): The name of the event type.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.detector.init.put(
                ctx, detector_id=value, event_type_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.detector.init.put detector_id=value, event_type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="put_detector",
        op_kwargs={
            "detectorId": detector_id,
            "description": description,
            "eventTypeName": event_type_name,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    resource_group_name: str,
    pattern_set_name: str,
    pattern_name: str,
    pattern: str,
    rank: int,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an log pattern to a LogPatternSet.

    Args:
        resource_group_name(str): The name of the resource group.
        pattern_set_name(str): The name of the log pattern set.
        pattern_name(str): The name of the log pattern.
        pattern(str): The log pattern. The pattern must be DFA compatible. Patterns that utilize forward lookahead or backreference constructions are not supported.
        rank(int): Rank of the log pattern. Must be a value between 1 and 1,000,000. The patterns are sorted by rank, so we recommend that you set your highest priority patterns with the lowest rank. A pattern of rank 1 will be the first to get matched to a log line. A pattern of rank 1,000,000 will be last to get matched. When you configure custom log patterns from the console, a Low severity pattern translates to a 750,000 rank. A Medium severity pattern translates to a 500,000 rank. And a High severity pattern translates to a 250,000 rank. Rank values less than 1 or greater than 1,000,000 are reserved for AWS-provided patterns. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.log_pattern.init.create(
                ctx,
                resource_group_name=value,
                pattern_set_name=value,
                pattern_name=value,
                pattern=value,
                rank=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.log_pattern.init.create resource_group_name=value, pattern_set_name=value, pattern_name=value, pattern=value, rank=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="create_log_pattern",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "PatternSetName": pattern_set_name,
            "PatternName": pattern_name,
            "Pattern": pattern,
            "Rank": rank,
        },
    )


async def delete(
    hub, ctx, resource_group_name: str, pattern_set_name: str, pattern_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified log pattern from a LogPatternSet.

    Args:
        resource_group_name(str): The name of the resource group.
        pattern_set_name(str): The name of the log pattern set.
        pattern_name(str): The name of the log pattern.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.log_pattern.init.delete(
                ctx, resource_group_name=value, pattern_set_name=value, pattern_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.log_pattern.init.delete resource_group_name=value, pattern_set_name=value, pattern_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="delete_log_pattern",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "PatternSetName": pattern_set_name,
            "PatternName": pattern_name,
        },
    )


async def describe(
    hub, ctx, resource_group_name: str, pattern_set_name: str, pattern_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Describe a specific log pattern from a LogPatternSet.

    Args:
        resource_group_name(str): The name of the resource group.
        pattern_set_name(str): The name of the log pattern set.
        pattern_name(str): The name of the log pattern.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.log_pattern.init.describe(
                ctx, resource_group_name=value, pattern_set_name=value, pattern_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.log_pattern.init.describe resource_group_name=value, pattern_set_name=value, pattern_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="describe_log_pattern",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "PatternSetName": pattern_set_name,
            "PatternName": pattern_name,
        },
    )


async def list_all(
    hub,
    ctx,
    resource_group_name: str,
    pattern_set_name: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the log patterns in the specific log LogPatternSet.

    Args:
        resource_group_name(str): The name of the resource group.
        pattern_set_name(str, optional): The name of the log pattern set. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.log_pattern.init.list_all(
                ctx, resource_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.log_pattern.init.list_all resource_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="list_log_patterns",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "PatternSetName": pattern_set_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    resource_group_name: str,
    pattern_set_name: str,
    pattern_name: str,
    pattern: str = None,
    rank: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a log pattern to a LogPatternSet.

    Args:
        resource_group_name(str): The name of the resource group.
        pattern_set_name(str): The name of the log pattern set.
        pattern_name(str): The name of the log pattern.
        pattern(str, optional): The log pattern. The pattern must be DFA compatible. Patterns that utilize forward lookahead or backreference constructions are not supported. Defaults to None.
        rank(int, optional): Rank of the log pattern. Must be a value between 1 and 1,000,000. The patterns are sorted by rank, so we recommend that you set your highest priority patterns with the lowest rank. A pattern of rank 1 will be the first to get matched to a log line. A pattern of rank 1,000,000 will be last to get matched. When you configure custom log patterns from the console, a Low severity pattern translates to a 750,000 rank. A Medium severity pattern translates to a 500,000 rank. And a High severity pattern translates to a 250,000 rank. Rank values less than 1 or greater than 1,000,000 are reserved for AWS-provided patterns. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.log_pattern.init.update(
                ctx, resource_group_name=value, pattern_set_name=value, pattern_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.log_pattern.init.update resource_group_name=value, pattern_set_name=value, pattern_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="update_log_pattern",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "PatternSetName": pattern_set_name,
            "PatternName": pattern_name,
            "Pattern": pattern,
            "Rank": rank,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, certificate_arn: str = None, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the IAM roles that are associated with the specified ACM (ACM) certificate. It also returns the name of the Amazon S3 bucket and the Amazon S3 object key where the certificate, certificate chain, and encrypted private key bundle are stored, and the ARN of the KMS key that's used to encrypt the private key.

    Args:
        certificate_arn(str, optional): The ARN of the ACM certificate for which to view the associated IAM roles, encryption keys, and Amazon S3 object information. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.associated.enclave_certificate_iam_role.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.associated.enclave_certificate_iam_role.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_associated_enclave_certificate_iam_roles",
        op_kwargs={"CertificateArn": certificate_arn, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of tags associated with the specified signaling channel.

    Args:
        next_token(str, optional): If you specify this parameter and the result of a ListTagsForResource call is truncated, the response includes a token that you can use in the next request to fetch the next batch of tags. . Defaults to None.
        resource_arn(str): The Amazon Resource Name (ARN) of the signaling channel for which you want to list tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.tags_for_.resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.tags_for_.resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="list_tags_for_resource",
        op_kwargs={"NextToken": next_token, "ResourceARN": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    alias: str,
    type_: str,
    plan: Dict,
    display_name: str = None,
    tags: List = None,
    idempotency_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Contacts are either the contacts that Incident Manager engages during an incident or the escalation plans that Incident Manager uses to engage contacts in phases during an incident.

    Args:
        alias(str): The short name to quickly identify a contact or escalation plan. The contact alias must be unique and identifiable. .
        display_name(str, optional): The full name of the contact or escalation plan. . Defaults to None.
        type_(str): To create an escalation plan use ESCALATION. To create a contact use PERSONAL.
        plan(Dict): A list of stages. A contact has an engagement plan with stages that contact specified contact channels. An escalation plan uses stages that contact specified contacts. .
        tags(List, optional): Adds a tag to the target. You can only tag resources created in the first Region of your replication set. . Defaults to None.
        idempotency_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.init.create(
                ctx, alias=value, type_=value, plan=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.init.create alias=value, type_=value, plan=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="create_contact",
        op_kwargs={
            "Alias": alias,
            "DisplayName": display_name,
            "Type": type_,
            "Plan": plan,
            "Tags": tags,
            "IdempotencyToken": idempotency_token,
        },
    )


async def delete(hub, ctx, contact_id: str) -> Dict:
    r"""
    **Autogenerated function**

    To remove a contact from Incident Manager, you can delete the contact. Deleting a contact removes them from all escalation plans and related response plans. Deleting an escalation plan removes it from all related response plans. You will have to recreate the contact and its contact channels before you can use it again.

    Args:
        contact_id(str): The Amazon Resource Name (ARN) of the contact that you're deleting.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.init.delete(ctx, contact_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.init.delete contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="delete_contact",
        op_kwargs={"ContactId": contact_id},
    )


async def get(hub, ctx, contact_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified contact or escalation plan.

    Args:
        contact_id(str): The Amazon Resource Name (ARN) of the contact or escalation plan.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.init.get(ctx, contact_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.init.get contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="get_contact",
        op_kwargs={"ContactId": contact_id},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    alias_prefix: str = None,
    type_: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all contacts and escalation plans in Incident Manager.

    Args:
        next_token(str, optional): The pagination token to continue to the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of contacts and escalation plans per page of results. Defaults to None.
        alias_prefix(str, optional): Used to list only contacts who's aliases start with the specified prefix. Defaults to None.
        type_(str, optional): The type of contact. A contact is type PERSONAL and an escalation plan is type ESCALATION. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="list_contacts",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "AliasPrefix": alias_prefix,
            "Type": type_,
        },
    )


async def update(
    hub, ctx, contact_id: str, display_name: str = None, plan: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the contact or escalation plan specified.

    Args:
        contact_id(str): The Amazon Resource Name (ARN) of the contact or escalation plan you're updating.
        display_name(str, optional): The full name of the contact or escalation plan. Defaults to None.
        plan(Dict, optional): A list of stages. A contact has an engagement plan with stages for specified contact channels. An escalation plan uses these stages to contact specified contacts. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.init.update(ctx, contact_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.init.update contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="update_contact",
        op_kwargs={"ContactId": contact_id, "DisplayName": display_name, "Plan": plan},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Add a tag to a Amazon SWF domain.  Amazon SWF supports a maximum of 50 tags per resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) for the Amazon SWF domain.
        tags(List): The list of tags to add to a domain.  Tags may only contain unicode letters, digits, whitespace, or these symbols: _ . : / = + - @.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Remove a tag from a Amazon SWF domain.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) for the Amazon SWF domain.
        tag_keys(List): The list of tags to remove from the Amazon SWF domain.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def check(hub, ctx, data_format: str, schema_definition: str) -> Dict:
    r"""
    **Autogenerated function**

    Validates the supplied schema. This call has no side effects, it simply validates using the supplied schema using DataFormat as the format. Since it does not take a schema set name, no compatibility checks are performed.

    Args:
        data_format(str): The data format of the schema definition. Currently AVRO and JSON are supported.
        schema_definition(str): The definition of the schema that has to be validated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.version.validity.check(
                ctx, data_format=value, schema_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.version.validity.check data_format=value, schema_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="check_schema_version_validity",
        op_kwargs={"DataFormat": data_format, "SchemaDefinition": schema_definition},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def check(hub, ctx, phone_number: str) -> Dict:
    r"""
    **Autogenerated function**

    Accepts a phone number and indicates whether the phone holder has opted out of receiving SMS messages from your account. You cannot send SMS messages to a number that is opted out. To resume sending messages, you can opt in the number by using the OptInPhoneNumber action.

    Args:
        phone_number(str): The phone number for which you want to check the opt out status.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.if_phone_number_is_opted_out.check(ctx, phone_number=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.if_phone_number_is_opted_out.check phone_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="check_if_phone_number_is_opted_out",
        op_kwargs={"phoneNumber": phone_number},
    )
